require 'bcrypt'
require 'dry-struct'
require 'securerandom'
require 'cabal/api/types'

module Cabal
  module API
    class User < Dry::Struct
      transform_keys(&:to_sym)

      attribute :email, Types::Strict::String
      attribute :access_key, Types::Strict::String
      attribute :secret_key, Types::Strict::String.default('')
      attribute :crypted_secret_key, Types::Strict::String.default('')
      attribute :created_at, Types::JSON::Time

      def crypto_key
        "#{email}::#{created_at}::#{access_key}"
      end

      def authenticated_with?(secret_key)
        return false unless crypted_secret_key.length > 0

        BCrypt::Password.new(crypted_secret_key) == secret_key
      end
    end
  end
end
